Enum amazon_sp_fulfillment_outbound::models::invalid_item_reason_code::InvalidItemReasonCode
source · [−]pub enum InvalidItemReasonCode {
InvalidValues,
DuplicateRequest,
NoCompletedShipItems,
NoReturnableQuantity,
}Expand description
InvalidItemReasonCode : A code for why the item is invalid for return. A code for why the item is invalid for return.
Variants
InvalidValues
DuplicateRequest
NoCompletedShipItems
NoReturnableQuantity